@@ -131,6 +131,6 @@ class Memorable(Corpus):
             if len(longest)>=min_len:
                 if verbose:
                     pretty = Memorable.pretty(longest, separator=' ', capitalize=True)
-                    yield {"length":len(hcode),"pretty":pretty,"key":key,"uid":uid,'num_attempts':num_attempts}
+                    yield {"length":len(hcode),"pretty":pretty,"key":key,"hashed key":code,"uid":uid,'num_attempts':num_attempts}
                 else:
                     yield key
\ No newline at end of file
